@@ -1,24 +1,19 @@
-
-#' @importFrom cli symbol cli_alert_success cli_alert_danger
-
 alert <- function(type, msg, ..., .envir = parent.frame()) {
-  switch (
+  switch(
     type,
-    success = cli_alert_success(msg, ..., .envir = .envir),
-    info = cli_alert_info(msg, ..., .envir = .envir),
-    warning = cli_alert_warning(msg, ..., .envir = .envir),
-    danger = cli_alert_danger(msg, ..., .envir = .envir)
+    success = cli::cli_alert_success(msg, ..., .envir = .envir),
+    info = cli::cli_alert_info(msg, ..., .envir = .envir),
+    warning = cli::cli_alert_warning(msg, ..., .envir = .envir),
+    danger = cli::cli_alert_danger(msg, ..., .envir = .envir)
   )
 }
 
-#' @importFrom cli get_spinner cli_status
-
 create_progress_bar <- function(state) {
   bar <- new.env(parent = emptyenv())
-  bar$spinner <- get_spinner()
+  bar$spinner <- cli::get_spinner()
   bar$spinner_state <- 1L
   if (should_show_progress_bar()) {
-    bar$status <- cli_status("Installing...", .auto_close = FALSE)
+    bar$status <- cli::cli_status("Installing...", .auto_close = FALSE)
   }
 
   bar$simple <- is_older_rstudio()
@@ -26,8 +21,6 @@ create_progress_bar <- function(state) {
   bar
 }
 
-#' @importFrom cli cli_status_update
-
 update_progress_bar <- function(state, tick = 0) {
   if (is.null(state$progress$status)) return()
 
@@ -41,8 +34,8 @@ update_progress_bar <- function(state, tick = 0) {
 
   chars <- progress_chars()
 
-  xbar <- make_install_bar(installed / total, built/total, width =  15)
-  xbuilt  <- make_progress_block(state, chars$build, built, total, building)
+  xbar <- make_install_bar(installed / total, built / total, width = 15)
+  xbuilt <- make_progress_block(state, chars$build, built, total, building)
   xinst <- make_progress_block(state, chars$inst, installed, total, installing)
   xmsg <- make_install_trailing_progress_msg(state)
 
@@ -59,7 +52,7 @@ update_progress_bar <- function(state, tick = 0) {
   }
 
   if (state$progress$simple) st <- cli::ansi_strip(st)
-  cli_status_update(state$progress$status, st)
+  cli::cli_status_update(state$progress$status, st)
 }
 
 ## p1 <= p2 must hold
@@ -75,7 +68,9 @@ make_install_bar <- function(p1, p2, width) {
   p2chars <- rep(chars$half, w2)
   xchars <- rep(" ", max(width - w1 - w2, 0))
   bar <- paste(
-    c(chars$lpar, p1chars, p2chars, xchars, chars$rpar), collapse = "")
+    c(chars$lpar, p1chars, p2chars, xchars, chars$rpar),
+    collapse = ""
+  )
 
   if (is_older_rstudio()) bar else cli::col_green(bar)
 }
@@ -85,17 +80,18 @@ make_progress_block <- function(state, sym, done, total, prog) {
   spin <- prgs$spinner$frames[[prgs$spinner_state]]
   prgs$spinner_state <- prgs$spinner_state %% length(prgs$spinner$frames) + 1L
   paste0(
-    sym, "  ",
-    done, "/", total,
+    sym,
+    "  ",
+    done,
+    "/",
+    total,
     if (prog) paste0(" ", spin, " ", prog) else "    "
   )
 }
 
-#' @importFrom cli cli_status_clear
-
 done_progress_bar <- function(state) {
   if (!is.null(state$progress$status)) {
-    cli_status_clear(state$progress$status)
+    cli::cli_status_clear(state$progress$status)
   }
 }
 
