@@ -1,4 +1,3 @@
-
 make_fake_deps <- function(...) {
   assert_that(all_named(list(...)))
 
@@ -27,8 +26,7 @@ make_fake_resolution1 <- function(ref, args = list()) {
     version = version,
     sources = c(
       sprintf("%s/%s/%s", mirror, repodir, filename),
-      sprintf("%s/%s/Archive/%s/%s", mirror, repodir, pref$package,
-              filename)
+      sprintf("%s/%s/Archive/%s/%s", mirror, repodir, pref$package, filename)
     ),
     dep_types = tolower(pkg_dep_types_hard())
   )
@@ -47,20 +45,24 @@ make_fake_resolution <- function(...) {
   pkgs <- list(...)
   assert_that(all_named(pkgs))
   ress <- lapply_with_names(
-    names(pkgs), function(n) make_fake_resolution1(n, pkgs[[n]]))
+    names(pkgs),
+    function(n) make_fake_resolution1(n, pkgs[[n]])
+  )
 
-  res  <- res_make_empty_df()
+  res <- res_make_empty_df()
   for (r in ress) res <- res_add_df_entries(res, r)
   res
 }
 
-describe_fake_error <- function(pkgs, policy = "lazy",
-                                config = current_config()) {
+describe_fake_error <- function(
+  pkgs,
+  policy = "lazy",
+  config = current_config()
+) {
   lp <- pkgplan_i_create_lp_problem(pkgs, config, policy)
   sol <- pkgplan_i_solve_lp_problem(lp)
 
   expect_true(sol$objval >= solve_dummy_obj - 1)
-  solution <- list(status = "FAILED", data = pkgs, problem = lp,
-                   solution = sol)
+  solution <- list(status = "FAILED", data = pkgs, problem = lp, solution = sol)
   describe_solution_error(pkgs, solution)
 }
