@@ -1,4 +1,3 @@
-
 expect_equal_named_lists <- function(object, expected, ...) {
   expect_true(!is.null(names(object)) && !is.null(names(expected)))
   expect_true(is.list(object) && is.list(expected))
@@ -7,15 +6,20 @@ expect_equal_named_lists <- function(object, expected, ...) {
   expect_equal(object, expected)
 }
 
-test_temp_file <- function(fileext = "", pattern = "test-file-",
-                           envir = parent.frame(), create = TRUE) {
+test_temp_file <- function(
+  fileext = "",
+  pattern = "test-file-",
+  envir = parent.frame(),
+  create = TRUE
+) {
   tmp <- tempfile(pattern = pattern, fileext = fileext)
   if (identical(envir, .GlobalEnv)) {
     message("Temporary files will _not_ be cleaned up")
   } else {
     withr::defer(
       try(unlink(tmp, recursive = TRUE, force = TRUE), silent = TRUE),
-      envir = envir)
+      envir = envir
+    )
   }
   if (create) {
     cat("", file = tmp)
@@ -31,10 +35,18 @@ test_temp_dir <- function(pattern = "test-dir-", envir = parent.frame()) {
   normalizePath(tmp)
 }
 
+# Create a temporary directory and switch the working directory to it
+local_temp_dir <- function(..., .local_envir = parent.frame()) {
+  tmp <- withr::local_tempdir(..., .local_envir = .local_envir)
+  withr::local_dir(tmp, .local_envir = .local_envir)
+  invisible(tmp)
+}
+
 test_package_root <- function() {
   x <- tryCatch(
     find_package_root(),
-    error = function(e) NULL)
+    error = function(e) NULL
+  )
 
   if (!is.null(x)) return(x)
 
@@ -57,9 +69,13 @@ skip_in_covr <- function() {
 
 # TODO: update this to cli.num_colors
 
-local_cli_config <- function(unicode = FALSE, dynamic = FALSE,
-                             ansi = FALSE, num_colors = 1,
-                             .local_envir = parent.frame()) {
+local_cli_config <- function(
+  unicode = FALSE,
+  dynamic = FALSE,
+  ansi = FALSE,
+  num_colors = 1,
+  .local_envir = parent.frame()
+) {
   withr::local_options(
     cli.dynamic = dynamic,
     cli.ansi = ansi,
@@ -80,7 +96,7 @@ pst <- function(...) suppressMessages(...)
 long_basename <- function(x) {
   # remove potential trailing slash
   l <- nchar(x)
-  x <- ifelse (substr(x, l, l) %in% c("/", "\\"), substr(x, 1, l - 1), x)
+  x <- ifelse(substr(x, l, l) %in% c("/", "\\"), substr(x, 1, l - 1), x)
   sub("^.*[/\\]", "", x)
 }
 
