@@ -1,4 +1,3 @@
-
 test_that("pkg_dep_types_*", {
   expect_snapshot(pkg_dep_types_hard())
   expect_snapshot(pkg_dep_types_soft())
@@ -65,12 +64,14 @@ test_that("parse_all_deps", {
 })
 
 test_that("resolve_ref_deps", {
-  dsc <- desc::desc(text = c(
-    "Suggests: covr, jsonlite, testthat (>= 3.1.0)",
-    "Imports: assertthat, curl, R6, rlang (>= 1.0.0)",
-    "Remotes: r-lib/covr",
-    "Config/Needs/website: pkgdown, r-lib/downlit"
-  ))
+  dsc <- desc::desc(
+    text = c(
+      "Suggests: covr, jsonlite, testthat (>= 3.1.0)",
+      "Imports: assertthat, curl, R6, rlang (>= 1.0.0)",
+      "Remotes: r-lib/covr",
+      "Config/Needs/website: pkgdown, r-lib/downlit"
+    )
+  )
   expect_snapshot(resolve_ref_deps(dsc$get_deps(), NA_character_, NULL))
   expect_snapshot(resolve_ref_deps(
     dsc$get_deps(),
@@ -80,21 +81,25 @@ test_that("resolve_ref_deps", {
 })
 
 test_that("resolve_ref_deps, package name from remote", {
-  dsc <- desc::desc(text = c(
-    "Imports: foo",
-    "Remotes: foo=r-lib/bar",
-    "Config/Needs/website: foobar=r-lib/baz"
-  ))
+  dsc <- desc::desc(
+    text = c(
+      "Imports: foo",
+      "Remotes: foo=r-lib/bar",
+      "Config/Needs/website: foobar=r-lib/baz"
+    )
+  )
   expect_snapshot(resolve_ref_deps(
     dsc$get_deps(),
     dsc$get("Remotes"),
     dsc$get(extra_config_fields(dsc$fields()))
   ))
 
-  dsc <- desc::desc(text = c(
-    "Imports: foo",
-    "Remotes: url::http://example.com"
-  ))
+  dsc <- desc::desc(
+    text = c(
+      "Imports: foo",
+      "Remotes: url::http://example.com"
+    )
+  )
   expect_snapshot(
     error = TRUE,
     resolve_ref_deps(
