@@ -1,4 +1,3 @@
-
 test_that("pkg_name_check", {
   mockery::stub(
     pkg_name_check,
@@ -9,24 +8,25 @@ test_that("pkg_name_check", {
 })
 
 test_that("async_pkg_name_check", {
-  expect_error(sy(async_pkg_name_check(11)))
-  expect_error(sy(async_pkg_name_check(c("a", "b"))))
-  expect_error(sy(async_pkg_name_check(NA_character_)))
-  expect_error(sy(async_pkg_name_check("x", 11)))
-  expect_error(sy(async_pkg_name_check("x", NA_character_)))
+  expect_snapshot(error = TRUE, {
+    sy(async_pkg_name_check(11))
+    sy(async_pkg_name_check(c("a", "b")))
+    sy(async_pkg_name_check(NA_character_))
+    sy(async_pkg_name_check("x", 11))
+    sy(async_pkg_name_check("x", NA_character_))
+  })
 
   calls <- 0L
   fun <- function(name) calls <<- calls + 1L
   mockery::stub(async_pkg_name_check, "async_pnc_basics", fun)
   mockery::stub(async_pkg_name_check, "async_wikipedia_get", fun)
   mockery::stub(async_pkg_name_check, "async_wiktionary_get", fun)
-  mockery::stub(async_pkg_name_check, "async_acromine_get", fun)
   mockery::stub(async_pkg_name_check, "async_sentiment_get", fun)
   mockery::stub(async_pkg_name_check, "async_urban_get", fun)
 
   ans <- sy(async_pkg_name_check("foo"))
   expect_s3_class(ans, "pkg_name_check")
-  expect_equal(sort(unlist(ans, use.names = FALSE)), 1:5)
+  expect_equal(sort(unlist(ans, use.names = FALSE)), 1:4)
 })
 
 # format.pkg_name_check via print
@@ -124,7 +124,9 @@ test_that("crandb_check", {
 })
 
 test_that("async_wikipedia_get", {
-  withr::local_envvar(PKG_NAME_CHECK_WIKIPEDIA_URL = check_app$url("/wikipedia"))
+  withr::local_envvar(
+    PKG_NAME_CHECK_WIKIPEDIA_URL = check_app$url("/wikipedia")
+  )
   ret <- synchronize(async_wikipedia_get("foobar"))
   expect_equal(ret$term, "foobar")
   expect_equal(ret$normalized, "Foobar")
@@ -214,70 +216,6 @@ test_that("format.pkg_name_check_wiktionary", {
 
 # clean_wiktionary_text
 
-test_that("async_acromine_get", {
-  resp <- fixture$get({
-    sy(async_acromine_get_query("fbi"))
-  })
-  mockery::stub(
-    async_acromine_get,
-    "async_acromine_get_query",
-    function(...) async_constant(resp)
-  )
-  ans <- sy(async_acromine_get("fbi"))
-  expect_s3_class(ans, "pkg_name_check_acromine")
-  expect_s3_class(ans, "tbl")
-  expect_true("Federal Bureau of Investigation" %in% ans$long_form)
-})
-
-test_that("async_acromine_get_query", {
-  local_edition(3)
-  local_reproducible_output()
-  withr::local_envvar(PKG_NAME_CHECK_ACROMINE_URL = check_app$url("/echo"))
-  ret <- synchronize(async_acromine_get_query("foobar"))
-  expect_snapshot(show_request(ret))
-})
-
-test_that("acromine_get_process", {
-  resp <- fixture$get({
-    sy(async_acromine_get_query("fbi"))
-  })
-  resp2 <- fixture$get({
-    sy(async_acromine_get_query("notanacronym"))
-  })
-  ans <- acromine_get_process("fbi", resp)
-  expect_s3_class(ans, "pkg_name_check_acromine")
-  expect_s3_class(ans, "tbl")
-  expect_true("Federal Bureau of Investigation" %in% ans$long_form)
-
-  ans2 <- acromine_get_process("notanacronym", resp2)
-  expect_s3_class(ans2, "pkg_name_check_acromine")
-  expect_s3_class(ans2, "tbl")
-  expect_equal(nrow(ans2), 0L)
-})
-
-test_that("format.pkg_name_check_acromine", {
-  local_edition(3)
-  local_reproducible_output()
-  resp <- fixture$get({
-    sy(async_acromine_get_query("fbi"))
-  })
-  resp2 <- fixture$get({
-    sy(async_acromine_get_query("notanacronym"))
-  })
-  resp3 <- fixture$get({
-    sy(async_acromine_get_query("cli"))
-  })
-
-  ans <- acromine_get_process("fbi", resp)
-  ans2 <- acromine_get_process("fbi", resp2)
-  ans3 <- acromine_get_process("fbi", resp3)
-  expect_snapshot({
-    writeLines(format(ans))
-    writeLines(format(ans2))
-    writeLines(format(ans3))
-  })
-})
-
 test_that("async_profanity_get", {
   resp <- fixture$get({
     sy(async_profanity_get_query("nope"))
@@ -415,7 +353,7 @@ test_that("format.pkg_name_check_urban", {
   expect_snapshot(writeLines(format(ans)))
   expect_snapshot(writeLines(format(ans2)))
 
-  ans <- ans[1,]
+  ans <- ans[1, ]
   ans$definition[1] <- paste(rep(ans$definition[1], 10), collapse = "\n")
   expect_snapshot(writeLines(format(ans)))
 })
@@ -427,15 +365,15 @@ test_that("clean_urban", {
 })
 
 test_that("async_pnc_bioc", {
-   expect_equal(sy(async_pnc_bioc("bim")), sy(pnc_bioc_false("bim")))
-   expect_equal(sy(async_pnc_bioc("yeast2")), sy(pnc_bioc_false("yeast2")))
+  expect_equal(sy(async_pnc_bioc("bim")), sy(pnc_bioc_false("bim")))
+  expect_equal(sy(async_pnc_bioc("yeast2")), sy(pnc_bioc_false("yeast2")))
 
-   mockery::stub(
-     async_pnc_bioc,
-     "async_pnc_bioc_web",
-     function(...) async_constant(pnc_bioc_false("Biobase"))
-   )
-   expect_equal(sy(async_pnc_bioc("Biobase")), sy(pnc_bioc_false("Biobase")))
+  mockery::stub(
+    async_pnc_bioc,
+    "async_pnc_bioc_web",
+    function(...) async_constant(pnc_bioc_false("Biobase"))
+  )
+  expect_equal(sy(async_pnc_bioc("Biobase")), sy(pnc_bioc_false("Biobase")))
 })
 
 # "pnc_bioc_false"
@@ -489,7 +427,9 @@ test_that("pnc_bioc_parse", {
   local_reproducible_output()
   withr::local_envvar(
     PKG_NAME_CHECK_BIOC_URL = check_app$url("/bioc/"),
-    PKG_NAME_CHECK_BIOC_ANN_URL = check_app$url("/biocann/src/contrib/PACKAGES.gz")
+    PKG_NAME_CHECK_BIOC_ANN_URL = check_app$url(
+      "/biocann/src/contrib/PACKAGES.gz"
+    )
   )
   pkg1 <- pnc_bioc_parse(sy(async_pnc_bioc_query("all"))[[1]])
   pkg2 <- pnc_bioc_parse(sy(async_pnc_bioc_query("all"))[[2]])
@@ -502,7 +442,9 @@ test_that("pnc_bioc_parse_pgz", {
   local_reproducible_output()
   withr::local_envvar(
     PKG_NAME_CHECK_BIOC_URL = check_app$url("/bioc/"),
-    PKG_NAME_CHECK_BIOC_ANN_URL = check_app$url("/biocann/src/contrib/PACKAGES.gz")
+    PKG_NAME_CHECK_BIOC_ANN_URL = check_app$url(
+      "/biocann/src/contrib/PACKAGES.gz"
+    )
   )
   pkg <- pnc_bioc_parse_pgz(sy(async_pnc_bioc_query("all"))[[3]])
   expect_snapshot(pkg)
