@@ -1,4 +1,3 @@
-
 test_that("resolving with a list", {
   conf <- current_config()
   cache <- list(package = pkgcache::package_cache$new(), metadata = NULL)
@@ -11,13 +10,20 @@ test_that("resolving with a list", {
   }
 
   foo_resolve <- function(remote, direct, config, cache, dependencies) {
-    list(ref = remote$ref, type = remote$type, package = remote$rest,
-         version = "1.0.0", sources = c("src1", "src2"), direct = direct)
+    list(
+      ref = remote$ref,
+      type = remote$type,
+      package = remote$rest,
+      version = "1.0.0",
+      sources = c("src1", "src2"),
+      direct = direct
+    )
   }
 
   res <- withr::with_options(
     list(pkg.remote_types = list(foo = list(resolve = foo_resolve))),
-    synchronise(do()))
+    synchronise(do())
+  )
 
   expect_equal(nrow(res), 2)
   expect_identical(res$ref, c("foo::bar", "foo::bar2"))
@@ -39,20 +45,30 @@ test_that("resolving with a tbl", {
   }
 
   foo_resolve <- function(remote, direct, config, cache, dependencies) {
-    data_frame(ref = remote$ref, type = c("type1", "type2"),
-           package = c("pkg1", "pkg2"), version = c("ver1", "ver2"),
-           sources = list(c("s11", "s12"), c("s21", "s22")),
-           direct = direct)
+    data_frame(
+      ref = remote$ref,
+      type = c("type1", "type2"),
+      package = c("pkg1", "pkg2"),
+      version = c("ver1", "ver2"),
+      sources = list(c("s11", "s12"), c("s21", "s22")),
+      direct = direct
+    )
   }
 
-  types <- list(foo = list(resolve = foo_resolve),
-                foo2 = list(resolve = foo_resolve))
+  types <- list(
+    foo = list(resolve = foo_resolve),
+    foo2 = list(resolve = foo_resolve)
+  )
   res <- withr::with_options(
     list(pkg.remote_types = types),
-    synchronise(do()))
+    synchronise(do())
+  )
 
   expect_equal(nrow(res), 4)
-  expect_identical(res$ref, c("foo::bar", "foo::bar", "foo2::bar2", "foo2::bar2"))
+  expect_identical(
+    res$ref,
+    c("foo::bar", "foo::bar", "foo2::bar2", "foo2::bar2")
+  )
   expect_identical(res$package, c("pkg1", "pkg2", "pkg1", "pkg2"))
   expect_identical(res$status, c("OK", "OK", "OK", "OK"))
   expect_true(is.list(res$remote[[1]]))
@@ -73,14 +89,21 @@ test_that("unknown deps are pushed in the queue", {
   }
 
   foo_resolve <- function(remote, direct, config, cache, dependencies) {
-    list(ref = remote$ref, type = remote$type, package = remote$rest,
-         version = "1.0.0", sources = c("src1", "src2"),
-         unknown_deps = "foo::bar2", direct = direct)
+    list(
+      ref = remote$ref,
+      type = remote$type,
+      package = remote$rest,
+      version = "1.0.0",
+      sources = c("src1", "src2"),
+      unknown_deps = "foo::bar2",
+      direct = direct
+    )
   }
 
   res <- withr::with_options(
     list(pkg.remote_types = list(foo = list(resolve = foo_resolve))),
-    synchronise(do()))
+    synchronise(do())
+  )
 
   expect_equal(nrow(res), 2)
   expect_identical(res$ref, c("foo::bar", "foo::bar2"))
@@ -101,18 +124,26 @@ test_that("unknown deps, tble", {
   }
 
   foo_resolve <- function(remote, direct, config, cache, dependencies) {
-    data_frame(ref = remote$ref, type = c("type1", "type2"),
-           package = c("pkg1", "pkg2"), version = c("ver1", "ver2"),
-           sources = list(c("s11", "s12"), c("s21", "s22")),
-           unknown_deps = "foo::bar2", direct = direct,
-           params = list(character()))
+    data_frame(
+      ref = remote$ref,
+      type = c("type1", "type2"),
+      package = c("pkg1", "pkg2"),
+      version = c("ver1", "ver2"),
+      sources = list(c("s11", "s12"), c("s21", "s22")),
+      unknown_deps = "foo::bar2",
+      direct = direct,
+      params = list(character())
+    )
   }
 
-  types <- list(foo = list(resolve = foo_resolve),
-                foo2 = list(resolve = foo_resolve))
+  types <- list(
+    foo = list(resolve = foo_resolve),
+    foo2 = list(resolve = foo_resolve)
+  )
   res <- withr::with_options(
     list(pkg.remote_types = types),
-    synchronise(do()))
+    synchronise(do())
+  )
 
   expect_equal(nrow(res), 4)
   expect_identical(res$ref, c("foo::bar", "foo::bar", "foo::bar2", "foo::bar2"))
@@ -142,7 +173,8 @@ test_that("error", {
 
   res <- withr::with_options(
     list(pkg.remote_types = list(foo = list(resolve = foo_resolve))),
-    synchronise(do()))
+    synchronise(do())
+  )
 
   expect_equal(nrow(res), 2)
   expect_equal(res$ref, c("foo::bar", "foo::bar2"))
@@ -160,18 +192,25 @@ test_that("installed refs are also resolved", {
   mkdirp(file.path(lib, "bar"))
   mkdirp(file.path(lib, "bar2"))
   cache <- list(package = pkgcache::package_cache$new(), metadata = NULL)
-  cache$installed  <- list(
+  cache$installed <- list(
     pkgs = data_frame(
       ref = paste0("installed::", lib, c("/bar", "/bar2")),
       type = "installed",
       status = "OK",
       package = c("bar", "bar2"),
-      version = "1.0.9", license = NA_character_, needscompilation = TRUE,
-      priority = NA_character_, md5sum = NA_character_,
-      platform = "source", rversion = "*", sources = list(NULL, NULL),
-      built = NA_character_, deps = list(NULL, NULL),
+      version = "1.0.9",
+      license = NA_character_,
+      needscompilation = TRUE,
+      priority = NA_character_,
+      md5sum = NA_character_,
+      platform = "source",
+      rversion = "*",
+      sources = list(NULL, NULL),
+      built = NA_character_,
+      deps = list(NULL, NULL),
       repotype = NA_character_,
-      sysreqs = NA_character_)
+      sysreqs = NA_character_
+    )
   )
 
   do <- function() {
@@ -182,15 +221,22 @@ test_that("installed refs are also resolved", {
   }
 
   foo_resolve <- function(remote, direct, config, cache, dependencies) {
-    list(ref = remote$ref, type = remote$type, package = remote$rest,
-         version = "1.0.0", sources = c("src1", "src2"), direct = direct)
+    list(
+      ref = remote$ref,
+      type = remote$type,
+      package = remote$rest,
+      version = "1.0.0",
+      sources = c("src1", "src2"),
+      direct = direct
+    )
   }
 
   types <- list(foo = list(resolve = foo_resolve))
 
   res <- withr::with_options(
     list(pkg.remote_types = types),
-    synchronise(do()))
+    synchronise(do())
+  )
 
   expect_equal(nrow(res), 4)
   expect_equal(res$ref[1:2], c("foo::bar", "foo::bar2"))
@@ -202,8 +248,10 @@ test_that("installed refs are also resolved", {
 test_that("explicit cran", {
   setup_fake_apps()
   conf <- current_config()
-  cache <- list(package = pkgcache::package_cache$new(),
-                metadata = pkgcache::get_cranlike_metadata_cache())
+  cache <- list(
+    package = pkgcache::package_cache$new(),
+    metadata = pkgcache::get_cranlike_metadata_cache()
+  )
   do <- function(refs) {
     res <- new_resolution(config = conf, cache = cache)
     res$push(.list = parse_pkg_refs(refs), direct = TRUE)
@@ -219,22 +267,26 @@ test_that("explicit cran", {
   expect_equal(res$status, rep("OK", nrow(res)))
   expect_equal(res$package, sub("^.*::", "", res$ref))
   expect_true(all(grepl(".", res$version, fixed = TRUE)))
-  expect_true(all(res$platform == "source" | ! res$needscompilation))
+  expect_true(all(res$platform == "source" | !res$needscompilation))
   expect_true(all(is.na(res$built) | res$platform != "source"))
   good_platforms <- c(
     default_platforms(),
     if (is_windows()) "i386+x86_64-w64-mingw32"
   )
   expect_true(all(res$platform %in% good_platforms))
-  expect_true(all(res$rversion %in%
-                  c(get_minor_r_version(current_r_version()), "*")))
+  expect_true(all(
+    res$rversion %in%
+      c(get_minor_r_version(current_r_version()), "*")
+  ))
   expect_true(is_character(res$repodir))
   expect_true(is_character(res$target))
   expect_true(all(vlapply(res$deps, inherits, what = "tbl")))
   expect_true("imports" %in% unlist(lapply(res$deps, "[[", "type")))
   expect_true("suggests" %in% unlist(lapply(res$deps, "[[", "type")))
-  expect_true(all(grepl("source|darwin", res$platform) |
-                  viapply(res$sources, length) == 1))
+  expect_true(all(
+    grepl("source|darwin", res$platform) |
+      viapply(res$sources, length) == 1
+  ))
   expect_true(all(vlapply(res$remote, inherits, what = "remote_ref")))
   expect_true(all(vlapply(res$error, identical, list())))
   ## TODO: metadata
@@ -245,7 +297,8 @@ test_that("standard", {
   conf <- current_config()
   cache <- list(
     package = pkgcache::package_cache$new(),
-    metadata = pkgcache::get_cranlike_metadata_cache())
+    metadata = pkgcache::get_cranlike_metadata_cache()
+  )
   do <- function(refs) {
     res <- new_resolution(config = conf, cache = cache)
     res$push(.list = parse_pkg_refs(refs), direct = TRUE)
@@ -255,28 +308,32 @@ test_that("standard", {
   res <- synchronise(do("dplyr"))
   expect_true(inherits(res, "tbl"))
   expect_true("dplyr" %in% res$ref)
-  expect_true(! any(grepl("::", res$ref)))
+  expect_true(!any(grepl("::", res$ref)))
   expect_equal(res$type, ifelse(res$ref == "cran::dplyr", "cran", "standard"))
   expect_equal(res$direct, res$ref == "dplyr")
   expect_equal(res$status, rep("OK", nrow(res)))
   expect_equal(res$package, sub("^.*::", "", res$ref))
   expect_true(all(grepl(".", res$version, fixed = TRUE)))
-  expect_true(all(res$platform == "source" | ! res$needscompilation))
+  expect_true(all(res$platform == "source" | !res$needscompilation))
   expect_true(all(is.na(res$built) | res$platform != "source"))
   good_platforms <- c(
     default_platforms(),
     if (is_windows()) "i386+x86_64-w64-mingw32"
   )
   expect_true(all(res$platform %in% good_platforms))
-  expect_true(all(res$rversion %in%
-                  c(get_minor_r_version(current_r_version()), "*")))
+  expect_true(all(
+    res$rversion %in%
+      c(get_minor_r_version(current_r_version()), "*")
+  ))
   expect_true(is_character(res$repodir))
   expect_true(is_character(res$target))
   expect_true(all(vlapply(res$deps, inherits, what = "tbl")))
   expect_true("imports" %in% unlist(lapply(res$deps, "[[", "type")))
   expect_true("suggests" %in% unlist(lapply(res$deps, "[[", "type")))
-  expect_true(all(grepl("source|darwin", res$platform) |
-                  viapply(res$sources, length) == 1))
+  expect_true(all(
+    grepl("source|darwin", res$platform) |
+      viapply(res$sources, length) == 1
+  ))
   expect_true(all(vlapply(res$remote, inherits, what = "remote_ref")))
   expect_true(all(vlapply(res$error, identical, list())))
   ## TODO: metadata
@@ -287,7 +344,8 @@ test_that("dependencies are honoured", {
   conf <- current_config()
   cache <- list(
     package = pkgcache::package_cache$new(),
-    metadata = pkgcache::get_cranlike_metadata_cache())
+    metadata = pkgcache::get_cranlike_metadata_cache()
+  )
   do <- function(refs, deps) {
     conf$set("dependencies", deps)
     res <- new_resolution(config = conf, cache = cache)
@@ -303,22 +361,26 @@ test_that("dependencies are honoured", {
   ## Exactly the specified ones
   res <- synchronise(do("cran::dplyr", "Imports"))
   imported <- unique(unlist(
-    lapply(res$deps, function(x) x$package[x$type == "imports"])))
+    lapply(res$deps, function(x) x$package[x$type == "imports"])
+  ))
   expect_true(all(res$package[!res$direct] %in% imported))
 
   ## NA means hard ones
   res <- synchronise(do("cran::dplyr", NA))
   hard <- c("imports", "depends", "linkingto")
   harddep <- unique(unlist(
-    lapply(res$deps, function(x) x$package[x$type %in% hard])))
+    lapply(res$deps, function(x) x$package[x$type %in% hard])
+  ))
   expect_true(all(res$package[!res$direct] %in% harddep))
 
   ## TRUE means hard + suggests on direct, hard only on rest
   res <- synchronise(do("cran::dplyr", TRUE))
   harddep <- unique(unlist(
-    lapply(res$deps, function(x) x$package[x$type %in% hard])))
+    lapply(res$deps, function(x) x$package[x$type %in% hard])
+  ))
   softdirectdep <- unique(unlist(
-    lapply(res$deps[res$direct], function(x) x$package[x$type == "suggests"])))
+    lapply(res$deps[res$direct], function(x) x$package[x$type == "suggests"])
+  ))
   indirect <- res$package[!res$direct]
   expect_true(all(indirect %in% harddep | indirect %in% softdirectdep))
 })
@@ -328,14 +390,15 @@ test_that("error if cannot find package", {
   conf <- current_config()
   cache <- list(
     package = pkgcache::package_cache$new(),
-    metadata = pkgcache::get_cranlike_metadata_cache())
+    metadata = pkgcache::get_cranlike_metadata_cache()
+  )
   do <- function(refs) {
     res <- new_resolution(config = conf, cache = cache)
     res$push(.list = parse_pkg_refs(refs), direct = TRUE)
     res$when_complete()
   }
 
-  bad <-  c("cran::thiscannotexistxxx", "neitherthisonexxx")
+  bad <- c("cran::thiscannotexistxxx", "neitherthisonexxx")
   res <- suppressMessages(synchronise(do(bad)))
   expect_equal(res$ref, bad)
   expect_equal(res$type, c("cran", "standard"))
@@ -349,7 +412,8 @@ test_that("dependency types", {
   conf$set("dependencies", TRUE)
   cache <- list(
     package = pkgcache::package_cache$new(),
-    metadata = pkgcache::get_cranlike_metadata_cache())
+    metadata = pkgcache::get_cranlike_metadata_cache()
+  )
   do <- function(refs) {
     res <- new_resolution(config = conf, cache = cache)
     res$push(.list = parse_pkg_refs(refs), direct = TRUE)
