@@ -1,12 +1,13 @@
-
 test_that("newer version preferred", {
   pkgs <- make_fake_resolution(
     `aa` = list(version = "1-0-1", platform = "source", direct = TRUE),
     `installed::/tmp/aa` = list(version = "1.2.0", type = "cran")
   )
-  lp <- pkgplan_i_create_lp_problem(pkgs,
-                                    config = current_config(),
-                                    policy = "upgrade")
+  lp <- pkgplan_i_create_lp_problem(
+    pkgs,
+    config = current_config(),
+    policy = "upgrade"
+  )
   sol <- pkgplan_i_solve_lp_problem(lp)
   expect_true(sol$objval < 1000)
   expect_equal(as.logical(sol$solution), c(FALSE, TRUE, FALSE))
@@ -15,9 +16,11 @@ test_that("newer version preferred", {
     `aa` = list(version = "1-0-1", platform = "source", direct = TRUE),
     `installed::/tmp/aa` = list(version = "1.0.0", type = "bioc")
   )
-  lp <- pkgplan_i_create_lp_problem(pkgs,
-                                    config = current_config(),
-                                    policy = "upgrade")
+  lp <- pkgplan_i_create_lp_problem(
+    pkgs,
+    config = current_config(),
+    policy = "upgrade"
+  )
   sol <- pkgplan_i_solve_lp_problem(lp)
   expect_true(sol$objval < 1000)
   expect_equal(as.logical(sol$solution), c(TRUE, FALSE, FALSE))
@@ -29,13 +32,14 @@ test_that("if newer fails, older is used", {
     `cran::aa` = list(version = "1-0-1", status = "FAILED"),
     `installed::/tmp/aa` = list(version = "1.0.0", type = "cran")
   )
-  lp <- pkgplan_i_create_lp_problem(pkgs,
-                                    config = current_config(),
-                                    policy = "upgrade")
+  lp <- pkgplan_i_create_lp_problem(
+    pkgs,
+    config = current_config(),
+    policy = "upgrade"
+  )
   sol <- pkgplan_i_solve_lp_problem(lp)
   expect_true(sol$objval < 1000)
   expect_equal(as.logical(sol$solution), c(FALSE, FALSE, TRUE, FALSE))
-
 })
 
 test_that("newer version if preferred in the dependencies", {
@@ -44,9 +48,11 @@ test_that("newer version if preferred in the dependencies", {
     `aa` = list(version = "1-0-1", platform = "source"),
     `installed::/tmp/aa` = list(version = "1.0.0")
   )
-  lp <- pkgplan_i_create_lp_problem(pkgs,
-                                    config = current_config(),
-                                    policy = "upgrade")
+  lp <- pkgplan_i_create_lp_problem(
+    pkgs,
+    config = current_config(),
+    policy = "upgrade"
+  )
   sol <- pkgplan_i_solve_lp_problem(lp)
   expect_true(sol$objval < 1000)
   expect_equal(as.logical(sol$solution), c(TRUE, TRUE, FALSE, FALSE))
@@ -59,9 +65,7 @@ test_that("binaries are still preferred over source", {
     `installed::/tmp/aa` = list(version = "0.9.9")
   )
   config <- current_config()$set("platforms", c("macos", "source"))
-  lp <- pkgplan_i_create_lp_problem(pkgs,
-                                    config = config,
-                                    policy = "upgrade")
+  lp <- pkgplan_i_create_lp_problem(pkgs, config = config, policy = "upgrade")
   sol <- pkgplan_i_solve_lp_problem(lp)
   expect_true(sol$objval < 1000)
   expect_equal(as.logical(sol$solution), c(TRUE, FALSE, FALSE, FALSE))
@@ -71,9 +75,7 @@ test_that("binaries are still preferred over source", {
     `aa` = list(version = "1.0.0", direct = TRUE, platform = "macos"),
     `installed::/tmp/aa` = list(version = "0.9.9")
   )
-  lp <- pkgplan_i_create_lp_problem(pkgs,
-                                    config = config,
-                                    policy = "upgrade")
+  lp <- pkgplan_i_create_lp_problem(pkgs, config = config, policy = "upgrade")
   sol <- pkgplan_i_solve_lp_problem(lp)
   expect_true(sol$objval < 1000)
   expect_equal(as.logical(sol$solution), c(FALSE, TRUE, FALSE, FALSE))
@@ -89,9 +91,7 @@ test_that("installed is still preferred over binaries", {
     )
   )
   config <- current_config()$set("platforms", c("macos", "source"))
-  lp <- pkgplan_i_create_lp_problem(pkgs,
-                                    config = config,
-                                    policy = "upgrade")
+  lp <- pkgplan_i_create_lp_problem(pkgs, config = config, policy = "upgrade")
   sol <- pkgplan_i_solve_lp_problem(lp)
   expect_true(sol$objval < 1000)
   expect_equal(as.logical(sol$solution), c(FALSE, FALSE, TRUE, FALSE))
@@ -104,8 +104,7 @@ test_that("installed is still preferred over binaries", {
       extra = list(list(repotype = "cran"))
     )
   )
-  lp <- pkgplan_i_create_lp_problem(pkgs, config = config,
-                                    policy = "upgrade")
+  lp <- pkgplan_i_create_lp_problem(pkgs, config = config, policy = "upgrade")
   sol <- pkgplan_i_solve_lp_problem(lp)
   expect_true(sol$objval < 1000)
   expect_equal(as.logical(sol$solution), c(FALSE, FALSE, TRUE, FALSE))
@@ -118,9 +117,7 @@ test_that("installed is still preferred over binaries", {
     `cran::aa` = list(version = "1.0.0", platform = "source"),
     `aa` = list(version = "1.0.0", direct = TRUE, platform = "macos")
   )
-  lp <- pkgplan_i_create_lp_problem(pkgs,
-                                    config = config,
-                                    policy = "upgrade")
+  lp <- pkgplan_i_create_lp_problem(pkgs, config = config, policy = "upgrade")
   sol <- pkgplan_i_solve_lp_problem(lp)
   expect_true(sol$objval < 1000)
   expect_equal(as.logical(sol$solution), c(TRUE, FALSE, FALSE, FALSE))
@@ -133,9 +130,7 @@ test_that("installed is still preferred over binaries", {
     ),
     `aa` = list(version = "1.0.0", direct = TRUE, platform = "macos")
   )
-  lp <- pkgplan_i_create_lp_problem(pkgs,
-                                    config = config,
-                                    policy = "upgrade")
+  lp <- pkgplan_i_create_lp_problem(pkgs, config = config, policy = "upgrade")
   sol <- pkgplan_i_solve_lp_problem(lp)
   expect_true(sol$objval < 1000)
   expect_equal(as.logical(sol$solution), c(FALSE, TRUE, FALSE, FALSE))
@@ -152,9 +147,7 @@ test_that("unqualified is cran/bioc", {
     )
   )
   config <- current_config()$set("platforms", c("macos", "source"))
-  lp <- pkgplan_i_create_lp_problem(pkgs,
-                                    config = config,
-                                    policy = "upgrade")
+  lp <- pkgplan_i_create_lp_problem(pkgs, config = config, policy = "upgrade")
   sol <- pkgplan_i_solve_lp_problem(lp)
   expect_true(sol$objval < 1000)
   expect_equal(as.logical(sol$solution), c(TRUE, FALSE, FALSE, FALSE))
