@@ -1,5 +1,5 @@
-
 test_that("sysreqs_platforms", {
+  withr::local_options(width = 200)
   expect_snapshot(print(sysreqs_platforms(), n = Inf))
 })
 
@@ -67,12 +67,13 @@ test_that("sysreqs_check_installed", {
     package = c("gsfonts", "libcurl4-openssl-dev"),
     provides = list(
       character(),
-      c("libcurl-dev",
+      c(
+        "libcurl-dev",
         "libcurl-ssl-dev",
         "libcurl3-dev",
         "libcurl3-openssl-dev",
         "libcurl4-dev"
-        )
+      )
     )
   )
 
@@ -111,7 +112,8 @@ test_that("sysreqs_check_installed", {
 
 test_that("async_parse_installed", {
   mockery::stub(
-    async_parse_installed, "pkgcache::parse_installed",
+    async_parse_installed,
+    "pkgcache::parse_installed",
     data_frame(Package = c("foo", "bar"))
   )
 
@@ -132,6 +134,7 @@ test_that("parse_sysreqs_platform", {
     parse_sysreqs_platform("x86_64-w64-mingw32")
     parse_sysreqs_platform("ubuntu")
     parse_sysreqs_platform("x86_64-px-linux-gnu-ubuntu-bar-baz")
+    parse_sysreqs_platform("ubuntu-22.04-libc++")
   })
 })
 
@@ -165,31 +168,40 @@ test_that("can_sudo_without_pw", {
 test_that("query, post_install", {
   setup_fake_sysreqs_app()
   withr::local_envvar(R_PKG_SYSREQS2 = "false")
-  expect_snapshot({
-    srq <- sysreqs_resolve("java", "ubuntu-22.04")
-    srq$total <- 1/3
-    srq
-  }, transform = transform_sysreqs_server)
+  expect_snapshot(
+    {
+      srq <- sysreqs_resolve("java", "ubuntu-22.04")
+      srq$total <- 1 / 3
+      srq
+    },
+    transform = transform_sysreqs_server
+  )
 })
 
 test_that("pre_install", {
   setup_fake_sysreqs_app()
   withr::local_envvar(R_PKG_SYSREQS2 = "false")
-  expect_snapshot({
-    srq <- sysreqs_resolve("this needs geos please", "ubuntu-16.04")
-    srq$total <- 1/3
-    srq
-  }, transform = transform_sysreqs_server)
+  expect_snapshot(
+    {
+      srq <- sysreqs_resolve("this needs geos please", "ubuntu-16.04")
+      srq$total <- 1 / 3
+      srq
+    },
+    transform = transform_sysreqs_server
+  )
 })
 
 test_that("multiple sysreqs", {
   setup_fake_sysreqs_app()
   withr::local_envvar(R_PKG_SYSREQS2 = "false")
-  expect_snapshot({
-    srq <- sysreqs_resolve("java and also libcurl", "ubuntu-22.04")
-    srq$total <- 1/3
-    srq
-  }, transform = transform_sysreqs_server)
+  expect_snapshot(
+    {
+      srq <- sysreqs_resolve("java and also libcurl", "ubuntu-22.04")
+      srq$total <- 1 / 3
+      srq
+    },
+    transform = transform_sysreqs_server
+  )
 })
 
 test_that("error, unknown os", {
